Chromium Code Reviews

Unified Diff: webrtc/modules/video_coding/encoded_frame.h

Issue 2816493002: Reland of Add content type information to encoded images and corresponding rtp extension header (Closed)
Patch Set: Rebase Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « webrtc/modules/video_coding/codecs/vp9/vp9_impl.cc ('k') | webrtc/modules/video_coding/encoded_frame.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/video_coding/encoded_frame.h
diff --git a/webrtc/modules/video_coding/encoded_frame.h b/webrtc/modules/video_coding/encoded_frame.h
index 840cd2056d594562799957559948f461e24b56a7..96f9d00d06e77780e9e6b5ac7b9f3125d63396f1 100644
--- a/webrtc/modules/video_coding/encoded_frame.h
+++ b/webrtc/modules/video_coding/encoded_frame.h
@@ -77,8 +77,12 @@ class VCMEncodedFrame : protected EncodedImage {
*/
VideoRotation rotation() const { return rotation_; }
/**
- * True if this frame is complete, false otherwise
- */
+ * Get video content type
+ */
+ VideoContentType contentType() const { return content_type_; }
+ /**
+ * True if this frame is complete, false otherwise
+ */
bool Complete() const { return _completeFrame; }
/**
* True if there's a frame missing before this frame
« no previous file with comments | « webrtc/modules/video_coding/codecs/vp9/vp9_impl.cc ('k') | webrtc/modules/video_coding/encoded_frame.cc » ('j') | no next file with comments »

Powered by Google App Engine